# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from proto.grpc import hdmapimpl_pb2 as proto_dot_grpc_dot_hdmapimpl__pb2


class HdmapImplStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.LoadMap = channel.unary_unary(
                '/hdmap_lib.HdmapImpl/LoadMap',
                request_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.LoadMapRequest.SerializeToString,
                response_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.LoadMapReply.FromString,
                )
        self.ReleaseMap = channel.unary_unary(
                '/hdmap_lib.HdmapImpl/ReleaseMap',
                request_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.ReleaseMapRequest.SerializeToString,
                response_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.ReleaseMapReply.FromString,
                )
        self.Reload = channel.unary_unary(
                '/hdmap_lib.HdmapImpl/Reload',
                request_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.ReloadRequest.SerializeToString,
                response_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.ReloadReply.FromString,
                )
        self.GetMap = channel.unary_unary(
                '/hdmap_lib.HdmapImpl/GetMap',
                request_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetMapRequest.SerializeToString,
                response_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetMapReply.FromString,
                )
        self.GetElementById = channel.unary_unary(
                '/hdmap_lib.HdmapImpl/GetElementById',
                request_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetElementByIdRequest.SerializeToString,
                response_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetElementByIdReply.FromString,
                )
        self.GetElements = channel.unary_unary(
                '/hdmap_lib.HdmapImpl/GetElements',
                request_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetElementsRequest.SerializeToString,
                response_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetElementsReply.FromString,
                )
        self.Getprojection = channel.unary_unary(
                '/hdmap_lib.HdmapImpl/Getprojection',
                request_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetProjectionRequest.SerializeToString,
                response_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetProjectionReply.FromString,
                )
        self.GetPoint = channel.unary_unary(
                '/hdmap_lib.HdmapImpl/GetPoint',
                request_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetPointRequest.SerializeToString,
                response_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetPointReply.FromString,
                )
        self.GetHeading = channel.unary_unary(
                '/hdmap_lib.HdmapImpl/GetHeading',
                request_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetHeadingRequest.SerializeToString,
                response_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetHeadingReply.FromString,
                )
        self.GetWidth = channel.unary_unary(
                '/hdmap_lib.HdmapImpl/GetWidth',
                request_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetWidthRequest.SerializeToString,
                response_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetWidthReply.FromString,
                )
        self.GetRoadWidth = channel.unary_unary(
                '/hdmap_lib.HdmapImpl/GetRoadWidth',
                request_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetRoadWidthRequest.SerializeToString,
                response_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetRoadWidthReply.FromString,
                )
        self.GetRelativeWidth = channel.unary_unary(
                '/hdmap_lib.HdmapImpl/GetRelativeWidth',
                request_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetRelativeWidthRequest.SerializeToString,
                response_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetRelativeWidthReply.FromString,
                )


class HdmapImplServicer(object):
    """Missing associated documentation comment in .proto file."""

    def LoadMap(self, request, context):
        """hdmap interface
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReleaseMap(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Reload(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMap(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetElementById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetElements(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Getprojection(self, request, context):
        """lane interface
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPoint(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetHeading(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWidth(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRoadWidth(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRelativeWidth(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_HdmapImplServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'LoadMap': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadMap,
                    request_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.LoadMapRequest.FromString,
                    response_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.LoadMapReply.SerializeToString,
            ),
            'ReleaseMap': grpc.unary_unary_rpc_method_handler(
                    servicer.ReleaseMap,
                    request_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.ReleaseMapRequest.FromString,
                    response_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.ReleaseMapReply.SerializeToString,
            ),
            'Reload': grpc.unary_unary_rpc_method_handler(
                    servicer.Reload,
                    request_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.ReloadRequest.FromString,
                    response_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.ReloadReply.SerializeToString,
            ),
            'GetMap': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMap,
                    request_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetMapRequest.FromString,
                    response_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetMapReply.SerializeToString,
            ),
            'GetElementById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetElementById,
                    request_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetElementByIdRequest.FromString,
                    response_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetElementByIdReply.SerializeToString,
            ),
            'GetElements': grpc.unary_unary_rpc_method_handler(
                    servicer.GetElements,
                    request_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetElementsRequest.FromString,
                    response_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetElementsReply.SerializeToString,
            ),
            'Getprojection': grpc.unary_unary_rpc_method_handler(
                    servicer.Getprojection,
                    request_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetProjectionRequest.FromString,
                    response_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetProjectionReply.SerializeToString,
            ),
            'GetPoint': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPoint,
                    request_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetPointRequest.FromString,
                    response_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetPointReply.SerializeToString,
            ),
            'GetHeading': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHeading,
                    request_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetHeadingRequest.FromString,
                    response_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetHeadingReply.SerializeToString,
            ),
            'GetWidth': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWidth,
                    request_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetWidthRequest.FromString,
                    response_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetWidthReply.SerializeToString,
            ),
            'GetRoadWidth': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRoadWidth,
                    request_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetRoadWidthRequest.FromString,
                    response_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetRoadWidthReply.SerializeToString,
            ),
            'GetRelativeWidth': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRelativeWidth,
                    request_deserializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetRelativeWidthRequest.FromString,
                    response_serializer=proto_dot_grpc_dot_hdmapimpl__pb2.GetRelativeWidthReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'hdmap_lib.HdmapImpl', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class HdmapImpl(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def LoadMap(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/hdmap_lib.HdmapImpl/LoadMap',
            proto_dot_grpc_dot_hdmapimpl__pb2.LoadMapRequest.SerializeToString,
            proto_dot_grpc_dot_hdmapimpl__pb2.LoadMapReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReleaseMap(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/hdmap_lib.HdmapImpl/ReleaseMap',
            proto_dot_grpc_dot_hdmapimpl__pb2.ReleaseMapRequest.SerializeToString,
            proto_dot_grpc_dot_hdmapimpl__pb2.ReleaseMapReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Reload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/hdmap_lib.HdmapImpl/Reload',
            proto_dot_grpc_dot_hdmapimpl__pb2.ReloadRequest.SerializeToString,
            proto_dot_grpc_dot_hdmapimpl__pb2.ReloadReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMap(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/hdmap_lib.HdmapImpl/GetMap',
            proto_dot_grpc_dot_hdmapimpl__pb2.GetMapRequest.SerializeToString,
            proto_dot_grpc_dot_hdmapimpl__pb2.GetMapReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetElementById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/hdmap_lib.HdmapImpl/GetElementById',
            proto_dot_grpc_dot_hdmapimpl__pb2.GetElementByIdRequest.SerializeToString,
            proto_dot_grpc_dot_hdmapimpl__pb2.GetElementByIdReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetElements(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/hdmap_lib.HdmapImpl/GetElements',
            proto_dot_grpc_dot_hdmapimpl__pb2.GetElementsRequest.SerializeToString,
            proto_dot_grpc_dot_hdmapimpl__pb2.GetElementsReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Getprojection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/hdmap_lib.HdmapImpl/Getprojection',
            proto_dot_grpc_dot_hdmapimpl__pb2.GetProjectionRequest.SerializeToString,
            proto_dot_grpc_dot_hdmapimpl__pb2.GetProjectionReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/hdmap_lib.HdmapImpl/GetPoint',
            proto_dot_grpc_dot_hdmapimpl__pb2.GetPointRequest.SerializeToString,
            proto_dot_grpc_dot_hdmapimpl__pb2.GetPointReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetHeading(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/hdmap_lib.HdmapImpl/GetHeading',
            proto_dot_grpc_dot_hdmapimpl__pb2.GetHeadingRequest.SerializeToString,
            proto_dot_grpc_dot_hdmapimpl__pb2.GetHeadingReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetWidth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/hdmap_lib.HdmapImpl/GetWidth',
            proto_dot_grpc_dot_hdmapimpl__pb2.GetWidthRequest.SerializeToString,
            proto_dot_grpc_dot_hdmapimpl__pb2.GetWidthReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRoadWidth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/hdmap_lib.HdmapImpl/GetRoadWidth',
            proto_dot_grpc_dot_hdmapimpl__pb2.GetRoadWidthRequest.SerializeToString,
            proto_dot_grpc_dot_hdmapimpl__pb2.GetRoadWidthReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRelativeWidth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/hdmap_lib.HdmapImpl/GetRelativeWidth',
            proto_dot_grpc_dot_hdmapimpl__pb2.GetRelativeWidthRequest.SerializeToString,
            proto_dot_grpc_dot_hdmapimpl__pb2.GetRelativeWidthReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
