syntax = "proto2";

package hdmap_lib;

import "proto/hdmap_lib/proto/geometry.proto";
import "proto/hdmap_lib/proto/id.proto";

message StopLine {
  // stop line unique id.
  optional Id id = 1;

  // stop line curve.
  optional Curve curve = 2;
}
