# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/hdmap_lib/proto/road.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import geometry_pb2 as proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2
from proto.hdmap_lib.proto import attribute_pb2 as proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2
from proto.hdmap_lib.proto import id_pb2 as proto_dot_hdmap__lib_dot_proto_dot_id__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/hdmap_lib/proto/road.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n proto/hdmap_lib/proto/road.proto\x12\thdmap_lib\x1a$proto/hdmap_lib/proto/geometry.proto\x1a%proto/hdmap_lib/proto/attribute.proto\x1a\x1eproto/hdmap_lib/proto/id.proto\".\n\x0bLaneSection\x12\x1f\n\x08lane_ids\x18\x01 \x03(\x0b\x32\r.hdmap_lib.Id\"\xf2\x08\n\x04Road\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12-\n\rlane_sections\x18\x02 \x03(\x0b\x32\x16.hdmap_lib.LaneSection\x12\"\n\x0bjunction_id\x18\x03 \x01(\x0b\x32\r.hdmap_lib.Id\x12\'\n\x10next_junction_id\x18\x05 \x01(\x0b\x32\r.hdmap_lib.Id\x12\'\n\x10prev_junction_id\x18\x06 \x01(\x0b\x32\r.hdmap_lib.Id\x12(\n\nattributes\x18\x04 \x03(\x0b\x32\x14.hdmap_lib.Attribute\x12\x0c\n\x04name\x18\x07 \x01(\t\x12&\n\x04type\x18\x08 \x01(\x0e\x32\x18.hdmap_lib.Road.RoadType\x12$\n\rprev_road_ids\x18\t \x03(\x0b\x32\r.hdmap_lib.Id\x12$\n\rnext_road_ids\x18\n \x03(\x0b\x32\r.hdmap_lib.Id\x12#\n\x07polygon\x18\x0b \x01(\x0b\x32\x12.hdmap_lib.Polygon\"\xd8\x05\n\x08RoadType\x12\x10\n\x0cUNKNOWN_ROAD\x10\x01\x12\x16\n\x12PORT_VERTICAL_ROAD\x10\x02\x12\x18\n\x14PORT_HORIZONTAL_ROAD\x10\x03\x12\x12\n\x0ePORT_YARD_ROAD\x10\x04\x12\x14\n\x10PORT_BRIDGE_ROAD\x10\x05\x12\x12\n\x0ePORT_DOCK_ROAD\x10\x06\x12\x16\n\x12PORT_REV_DOCK_ROAD\x10\x07\x12\x14\n\x10PORT_GIRDER_ROAD\x10\x08\x12\x18\n\x14PORT_REV_GIRDER_ROAD\x10\t\x12\x13\n\x0fPORT_CROSS_ROAD\x10\n\x12 \n\x1cPORT_YARD_ENTRANCE_EXIT_ROAD\x10\x0b\x12\"\n\x1ePORT_BRIDGE_ENTRANCE_EXIT_ROAD\x10\x0c\x12\x19\n\x15PORT_VESSEL_HEAD_ROAD\x10\r\x12\x19\n\x15PORT_VESSEL_TAIL_ROAD\x10\x0e\x12\x1e\n\x1aPORT_VESSEL_HEAD_TAIL_ROAD\x10\x0f\x12\x14\n\x10PORT_GANTRY_ROAD\x10\x10\x12\x13\n\x0fPORT_CRANE_ROAD\x10\x11\x12\x16\n\x12PORT_CHARGING_AREA\x10\x12\x12\x14\n\x10\x43ITY_NORMAL_ROAD\x10\x13\x12\x13\n\x0f\x43ITY_CROSS_ROAD\x10\x14\x12\r\n\tRAMP_ROAD\x10\x15\x12\x17\n\x13HIGHWAY_NORMAL_ROAD\x10\x16\x12\x0f\n\x0b\x42RIDGE_ROAD\x10\x17\x12\x0f\n\x0bTUNNEL_ROAD\x10\x18\x12\x10\n\x0c\x46LYOVER_ROAD\x10\x19\x12\x13\n\x0fROUNDABOUT_ROAD\x10\x1a\x12\x12\n\x0eLETT_TURN_ONLY\x10\x1b\x12\x13\n\x0fRIGHT_TURN_ONLY\x10\x1c\x12\x0f\n\x0bU_TURN_ONLY\x10\x1d\x12\"\n\x1ePARKING_LOT_ENTRANCE_EXIT_ROAD\x10\x1e\x12\x14\n\x10PARKING_LOT_ROAD\x10\x1f'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_id__pb2.DESCRIPTOR,])



_ROAD_ROADTYPE = _descriptor.EnumDescriptor(
  name='RoadType',
  full_name='hdmap_lib.Road.RoadType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_ROAD', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_VERTICAL_ROAD', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_HORIZONTAL_ROAD', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_YARD_ROAD', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_BRIDGE_ROAD', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_DOCK_ROAD', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_REV_DOCK_ROAD', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_GIRDER_ROAD', index=7, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_REV_GIRDER_ROAD', index=8, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_CROSS_ROAD', index=9, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_YARD_ENTRANCE_EXIT_ROAD', index=10, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_BRIDGE_ENTRANCE_EXIT_ROAD', index=11, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_VESSEL_HEAD_ROAD', index=12, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_VESSEL_TAIL_ROAD', index=13, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_VESSEL_HEAD_TAIL_ROAD', index=14, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_GANTRY_ROAD', index=15, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_CRANE_ROAD', index=16, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PORT_CHARGING_AREA', index=17, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CITY_NORMAL_ROAD', index=18, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CITY_CROSS_ROAD', index=19, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RAMP_ROAD', index=20, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHWAY_NORMAL_ROAD', index=21, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRIDGE_ROAD', index=22, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TUNNEL_ROAD', index=23, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLYOVER_ROAD', index=24, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROUNDABOUT_ROAD', index=25, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LETT_TURN_ONLY', index=26, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_TURN_ONLY', index=27, number=28,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='U_TURN_ONLY', index=28, number=29,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_LOT_ENTRANCE_EXIT_ROAD', index=29, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARKING_LOT_ROAD', index=30, number=31,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=615,
  serialized_end=1343,
)
_sym_db.RegisterEnumDescriptor(_ROAD_ROADTYPE)


_LANESECTION = _descriptor.Descriptor(
  name='LaneSection',
  full_name='hdmap_lib.LaneSection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_ids', full_name='hdmap_lib.LaneSection.lane_ids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=156,
  serialized_end=202,
)


_ROAD = _descriptor.Descriptor(
  name='Road',
  full_name='hdmap_lib.Road',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.Road.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_sections', full_name='hdmap_lib.Road.lane_sections', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction_id', full_name='hdmap_lib.Road.junction_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_junction_id', full_name='hdmap_lib.Road.next_junction_id', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prev_junction_id', full_name='hdmap_lib.Road.prev_junction_id', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='hdmap_lib.Road.attributes', index=5,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='hdmap_lib.Road.name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='hdmap_lib.Road.type', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prev_road_ids', full_name='hdmap_lib.Road.prev_road_ids', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_road_ids', full_name='hdmap_lib.Road.next_road_ids', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon', full_name='hdmap_lib.Road.polygon', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ROAD_ROADTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=1343,
)

_LANESECTION.fields_by_name['lane_ids'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_ROAD.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_ROAD.fields_by_name['lane_sections'].message_type = _LANESECTION
_ROAD.fields_by_name['junction_id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_ROAD.fields_by_name['next_junction_id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_ROAD.fields_by_name['prev_junction_id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_ROAD.fields_by_name['attributes'].message_type = proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2._ATTRIBUTE
_ROAD.fields_by_name['type'].enum_type = _ROAD_ROADTYPE
_ROAD.fields_by_name['prev_road_ids'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_ROAD.fields_by_name['next_road_ids'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_ROAD.fields_by_name['polygon'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._POLYGON
_ROAD_ROADTYPE.containing_type = _ROAD
DESCRIPTOR.message_types_by_name['LaneSection'] = _LANESECTION
DESCRIPTOR.message_types_by_name['Road'] = _ROAD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LaneSection = _reflection.GeneratedProtocolMessageType('LaneSection', (_message.Message,), {
  'DESCRIPTOR' : _LANESECTION,
  '__module__' : 'proto.hdmap_lib.proto.road_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LaneSection)
  })
_sym_db.RegisterMessage(LaneSection)

Road = _reflection.GeneratedProtocolMessageType('Road', (_message.Message,), {
  'DESCRIPTOR' : _ROAD,
  '__module__' : 'proto.hdmap_lib.proto.road_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.Road)
  })
_sym_db.RegisterMessage(Road)


# @@protoc_insertion_point(module_scope)
