# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/hdmap_lib/proto/stop_line.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import geometry_pb2 as proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2
from proto.hdmap_lib.proto import id_pb2 as proto_dot_hdmap__lib_dot_proto_dot_id__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/hdmap_lib/proto/stop_line.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%proto/hdmap_lib/proto/stop_line.proto\x12\thdmap_lib\x1a$proto/hdmap_lib/proto/geometry.proto\x1a\x1eproto/hdmap_lib/proto/id.proto\"F\n\x08StopLine\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12\x1f\n\x05\x63urve\x18\x02 \x01(\x0b\x32\x10.hdmap_lib.Curve'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_id__pb2.DESCRIPTOR,])




_STOPLINE = _descriptor.Descriptor(
  name='StopLine',
  full_name='hdmap_lib.StopLine',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.StopLine.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curve', full_name='hdmap_lib.StopLine.curve', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=122,
  serialized_end=192,
)

_STOPLINE.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_STOPLINE.fields_by_name['curve'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._CURVE
DESCRIPTOR.message_types_by_name['StopLine'] = _STOPLINE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StopLine = _reflection.GeneratedProtocolMessageType('StopLine', (_message.Message,), {
  'DESCRIPTOR' : _STOPLINE,
  '__module__' : 'proto.hdmap_lib.proto.stop_line_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.StopLine)
  })
_sym_db.RegisterMessage(StopLine)


# @@protoc_insertion_point(module_scope)
