# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/hdmap_lib/proto/map.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import header_pb2 as proto_dot_hdmap__lib_dot_proto_dot_header__pb2
from proto.hdmap_lib.proto import crosswalk_pb2 as proto_dot_hdmap__lib_dot_proto_dot_crosswalk__pb2
from proto.hdmap_lib.proto import geometry_pb2 as proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2
from proto.hdmap_lib.proto import junction_pb2 as proto_dot_hdmap__lib_dot_proto_dot_junction__pb2
from proto.hdmap_lib.proto import lane_pb2 as proto_dot_hdmap__lib_dot_proto_dot_lane__pb2
from proto.hdmap_lib.proto import relation_pb2 as proto_dot_hdmap__lib_dot_proto_dot_relation__pb2
from proto.hdmap_lib.proto import road_pb2 as proto_dot_hdmap__lib_dot_proto_dot_road__pb2
from proto.hdmap_lib.proto import signal_pb2 as proto_dot_hdmap__lib_dot_proto_dot_signal__pb2
from proto.hdmap_lib.proto import stop_line_pb2 as proto_dot_hdmap__lib_dot_proto_dot_stop__line__pb2
from proto.hdmap_lib.proto import parking_space_pb2 as proto_dot_hdmap__lib_dot_proto_dot_parking__space__pb2
from proto.hdmap_lib.proto import poi_pb2 as proto_dot_hdmap__lib_dot_proto_dot_poi__pb2
from proto.hdmap_lib.proto import object_pb2 as proto_dot_hdmap__lib_dot_proto_dot_object__pb2
from proto.hdmap_lib.proto import lane_link_pb2 as proto_dot_hdmap__lib_dot_proto_dot_lane__link__pb2
from proto.hdmap_lib.proto import road_link_pb2 as proto_dot_hdmap__lib_dot_proto_dot_road__link__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/hdmap_lib/proto/map.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fproto/hdmap_lib/proto/map.proto\x12\thdmap_lib\x1a\"proto/hdmap_lib/proto/header.proto\x1a%proto/hdmap_lib/proto/crosswalk.proto\x1a$proto/hdmap_lib/proto/geometry.proto\x1a$proto/hdmap_lib/proto/junction.proto\x1a proto/hdmap_lib/proto/lane.proto\x1a$proto/hdmap_lib/proto/relation.proto\x1a proto/hdmap_lib/proto/road.proto\x1a\"proto/hdmap_lib/proto/signal.proto\x1a%proto/hdmap_lib/proto/stop_line.proto\x1a)proto/hdmap_lib/proto/parking_space.proto\x1a\x1fproto/hdmap_lib/proto/poi.proto\x1a\"proto/hdmap_lib/proto/object.proto\x1a%proto/hdmap_lib/proto/lane_link.proto\x1a%proto/hdmap_lib/proto/road_link.proto\"\xd4\x04\n\x03Map\x12!\n\x06header\x18\t \x01(\x0b\x32\x11.hdmap_lib.Header\x12\x1e\n\x05roads\x18\x01 \x03(\x0b\x32\x0f.hdmap_lib.Road\x12(\n\x05lines\x18\x02 \x03(\x0b\x32\x19.hdmap_lib.LineStringData\x12\x1e\n\x05lanes\x18\x03 \x03(\x0b\x32\x0f.hdmap_lib.Lane\x12&\n\tjunctions\x18\x04 \x03(\x0b\x32\x13.hdmap_lib.Junction\x12(\n\ncrosswalks\x18\x05 \x03(\x0b\x32\x14.hdmap_lib.Crosswalk\x12\"\n\x07signals\x18\x06 \x03(\x0b\x32\x11.hdmap_lib.Signal\x12\'\n\nstop_lines\x18\n \x03(\x0b\x32\x13.hdmap_lib.StopLine\x12/\n\x0eparking_spaces\x18\x0b \x03(\x0b\x32\x17.hdmap_lib.ParkingSpace\x12\x34\n\x11pull_over_regions\x18\x0c \x03(\x0b\x32\x19.hdmap_lib.PullOverRegion\x12\x1c\n\x04pois\x18\r \x03(\x0b\x32\x0e.hdmap_lib.Poi\x12\"\n\x07objects\x18\x0f \x03(\x0b\x32\x11.hdmap_lib.Object\x12&\n\trelations\x18\x08 \x03(\x0b\x32\x13.hdmap_lib.Relation\x12\'\n\nlane_links\x18\x10 \x03(\x0b\x32\x13.hdmap_lib.LaneLink\x12\'\n\nroad_links\x18\x11 \x03(\x0b\x32\x13.hdmap_lib.RoadLink'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_header__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_crosswalk__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_junction__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_lane__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_relation__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_road__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_signal__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_stop__line__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_parking__space__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_poi__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_object__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_lane__link__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_road__link__pb2.DESCRIPTOR,])




_MAP = _descriptor.Descriptor(
  name='Map',
  full_name='hdmap_lib.Map',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='hdmap_lib.Map.header', index=0,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roads', full_name='hdmap_lib.Map.roads', index=1,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lines', full_name='hdmap_lib.Map.lines', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lanes', full_name='hdmap_lib.Map.lanes', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junctions', full_name='hdmap_lib.Map.junctions', index=4,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crosswalks', full_name='hdmap_lib.Map.crosswalks', index=5,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signals', full_name='hdmap_lib.Map.signals', index=6,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_lines', full_name='hdmap_lib.Map.stop_lines', index=7,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_spaces', full_name='hdmap_lib.Map.parking_spaces', index=8,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pull_over_regions', full_name='hdmap_lib.Map.pull_over_regions', index=9,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pois', full_name='hdmap_lib.Map.pois', index=10,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='objects', full_name='hdmap_lib.Map.objects', index=11,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relations', full_name='hdmap_lib.Map.relations', index=12,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_links', full_name='hdmap_lib.Map.lane_links', index=13,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='road_links', full_name='hdmap_lib.Map.road_links', index=14,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=569,
  serialized_end=1165,
)

_MAP.fields_by_name['header'].message_type = proto_dot_hdmap__lib_dot_proto_dot_header__pb2._HEADER
_MAP.fields_by_name['roads'].message_type = proto_dot_hdmap__lib_dot_proto_dot_road__pb2._ROAD
_MAP.fields_by_name['lines'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._LINESTRINGDATA
_MAP.fields_by_name['lanes'].message_type = proto_dot_hdmap__lib_dot_proto_dot_lane__pb2._LANE
_MAP.fields_by_name['junctions'].message_type = proto_dot_hdmap__lib_dot_proto_dot_junction__pb2._JUNCTION
_MAP.fields_by_name['crosswalks'].message_type = proto_dot_hdmap__lib_dot_proto_dot_crosswalk__pb2._CROSSWALK
_MAP.fields_by_name['signals'].message_type = proto_dot_hdmap__lib_dot_proto_dot_signal__pb2._SIGNAL
_MAP.fields_by_name['stop_lines'].message_type = proto_dot_hdmap__lib_dot_proto_dot_stop__line__pb2._STOPLINE
_MAP.fields_by_name['parking_spaces'].message_type = proto_dot_hdmap__lib_dot_proto_dot_parking__space__pb2._PARKINGSPACE
_MAP.fields_by_name['pull_over_regions'].message_type = proto_dot_hdmap__lib_dot_proto_dot_parking__space__pb2._PULLOVERREGION
_MAP.fields_by_name['pois'].message_type = proto_dot_hdmap__lib_dot_proto_dot_poi__pb2._POI
_MAP.fields_by_name['objects'].message_type = proto_dot_hdmap__lib_dot_proto_dot_object__pb2._OBJECT
_MAP.fields_by_name['relations'].message_type = proto_dot_hdmap__lib_dot_proto_dot_relation__pb2._RELATION
_MAP.fields_by_name['lane_links'].message_type = proto_dot_hdmap__lib_dot_proto_dot_lane__link__pb2._LANELINK
_MAP.fields_by_name['road_links'].message_type = proto_dot_hdmap__lib_dot_proto_dot_road__link__pb2._ROADLINK
DESCRIPTOR.message_types_by_name['Map'] = _MAP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Map = _reflection.GeneratedProtocolMessageType('Map', (_message.Message,), {
  'DESCRIPTOR' : _MAP,
  '__module__' : 'proto.hdmap_lib.proto.map_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.Map)
  })
_sym_db.RegisterMessage(Map)


# @@protoc_insertion_point(module_scope)
