# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/hdmap_lib/proto/crosswalk.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import attribute_pb2 as proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2
from proto.hdmap_lib.proto import geometry_pb2 as proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2
from proto.hdmap_lib.proto import id_pb2 as proto_dot_hdmap__lib_dot_proto_dot_id__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/hdmap_lib/proto/crosswalk.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%proto/hdmap_lib/proto/crosswalk.proto\x12\thdmap_lib\x1a%proto/hdmap_lib/proto/attribute.proto\x1a$proto/hdmap_lib/proto/geometry.proto\x1a\x1eproto/hdmap_lib/proto/id.proto\"\xc8\x01\n\tCrosswalk\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12\'\n\rleft_boundary\x18\x02 \x01(\x0b\x32\x10.hdmap_lib.Curve\x12(\n\x0eright_boundary\x18\x03 \x01(\x0b\x32\x10.hdmap_lib.Curve\x12(\n\nattributes\x18\x04 \x03(\x0b\x32\x14.hdmap_lib.Attribute\x12#\n\x07polygon\x18\x05 \x01(\x0b\x32\x12.hdmap_lib.Polygon'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_id__pb2.DESCRIPTOR,])




_CROSSWALK = _descriptor.Descriptor(
  name='Crosswalk',
  full_name='hdmap_lib.Crosswalk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.Crosswalk.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_boundary', full_name='hdmap_lib.Crosswalk.left_boundary', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_boundary', full_name='hdmap_lib.Crosswalk.right_boundary', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='hdmap_lib.Crosswalk.attributes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon', full_name='hdmap_lib.Crosswalk.polygon', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=162,
  serialized_end=362,
)

_CROSSWALK.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_CROSSWALK.fields_by_name['left_boundary'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._CURVE
_CROSSWALK.fields_by_name['right_boundary'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._CURVE
_CROSSWALK.fields_by_name['attributes'].message_type = proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2._ATTRIBUTE
_CROSSWALK.fields_by_name['polygon'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._POLYGON
DESCRIPTOR.message_types_by_name['Crosswalk'] = _CROSSWALK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Crosswalk = _reflection.GeneratedProtocolMessageType('Crosswalk', (_message.Message,), {
  'DESCRIPTOR' : _CROSSWALK,
  '__module__' : 'proto.hdmap_lib.proto.crosswalk_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.Crosswalk)
  })
_sym_db.RegisterMessage(Crosswalk)


# @@protoc_insertion_point(module_scope)
