# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/hdmap_lib/proto/lane_link.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import id_pb2 as proto_dot_hdmap__lib_dot_proto_dot_id__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/hdmap_lib/proto/lane_link.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%proto/hdmap_lib/proto/lane_link.proto\x12\thdmap_lib\x1a\x1eproto/hdmap_lib/proto/id.proto\"j\n\x08LaneLink\x12 \n\tfrom_lane\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12\x0e\n\x06\x66rom_s\x18\x02 \x01(\x01\x12\x1e\n\x07to_lane\x18\x03 \x01(\x0b\x32\r.hdmap_lib.Id\x12\x0c\n\x04to_s\x18\x04 \x01(\x01'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_id__pb2.DESCRIPTOR,])




_LANELINK = _descriptor.Descriptor(
  name='LaneLink',
  full_name='hdmap_lib.LaneLink',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_lane', full_name='hdmap_lib.LaneLink.from_lane', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_s', full_name='hdmap_lib.LaneLink.from_s', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_lane', full_name='hdmap_lib.LaneLink.to_lane', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_s', full_name='hdmap_lib.LaneLink.to_s', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=190,
)

_LANELINK.fields_by_name['from_lane'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LANELINK.fields_by_name['to_lane'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
DESCRIPTOR.message_types_by_name['LaneLink'] = _LANELINK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LaneLink = _reflection.GeneratedProtocolMessageType('LaneLink', (_message.Message,), {
  'DESCRIPTOR' : _LANELINK,
  '__module__' : 'proto.hdmap_lib.proto.lane_link_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LaneLink)
  })
_sym_db.RegisterMessage(LaneLink)


# @@protoc_insertion_point(module_scope)
