# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/hdmap_lib/proto/object.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import id_pb2 as proto_dot_hdmap__lib_dot_proto_dot_id__pb2
from proto.hdmap_lib.proto import geometry_pb2 as proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2
from proto.hdmap_lib.proto import attribute_pb2 as proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/hdmap_lib/proto/object.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"proto/hdmap_lib/proto/object.proto\x12\thdmap_lib\x1a\x1eproto/hdmap_lib/proto/id.proto\x1a$proto/hdmap_lib/proto/geometry.proto\x1a%proto/hdmap_lib/proto/attribute.proto\"\xaa\x06\n\x06Object\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12$\n\x04type\x18\x02 \x01(\x0e\x32\x16.hdmap_lib.Object.Type\x12#\n\x07polygon\x18\x03 \x01(\x0b\x32\x12.hdmap_lib.Polygon\x12\x0e\n\x06height\x18\x04 \x01(\x01\x12\x0c\n\x04text\x18\x05 \x01(\t\x12/\n\ncross_type\x18\x06 \x01(\x0e\x32\x1b.hdmap_lib.Object.CrossType\x12(\n\nattributes\x18\x07 \x03(\x0b\x32\x14.hdmap_lib.Attribute\"\xdd\x03\n\x04Type\x12\x08\n\x04NONE\x10\x01\x12\r\n\tSIDE_WALK\x10\x02\x12\x11\n\rCHARGING_PILE\x10\x03\x12\x08\n\x04TEXT\x10\x04\x12\x0f\n\x0bGROUND_SIGN\x10\x05\x12\x0f\n\x0b\x42US_STATION\x10\x06\x12\x10\n\x0cTRAFFIC_SIGN\x10\x07\x12\x19\n\x15HEIGHT_LIMIT_OBSTACLE\x10\x08\x12\x0c\n\x08\x42UILDING\x10\t\x12\x15\n\x11\x44\x45\x43\x45LERATION_ZONE\x10\n\x12\x19\n\x15NON_SLIP_RAMP_MARKING\x10\x0b\x12\x12\n\x0e\x44IVERSION_LINE\x10\x0c\x12\x11\n\rLOCK_PAVILION\x10\r\x12\r\n\tREST_AREA\x10\x0e\x12\x16\n\x12WORKING_QUEUE_AREA\x10\x0f\x12\x11\n\rCHARGING_AREA\x10\x10\x12\x14\n\x10GRASS_GREEN_BELT\x10\x11\x12\x15\n\x11PEDESTRIAN_ISLAND\x10\x12\x12\x1a\n\x16\x45MERGENCY_PARKING_ZONE\x10\x13\x12\x12\n\x0e\x46ORBIDDEN_AREA\x10\x14\x12\x0e\n\nCLEAR_AREA\x10\x15\x12\x0e\n\nTRANSITION\x10\x16\x12\x0c\n\x08OBSTACLE\x10\x17\x12\x13\n\x0f\x42USH_GREEN_BELT\x10\x18\x12\x0f\n\x0b\x42RIDGE_EDGE\x10\x19\"a\n\tCrossType\x12\x15\n\x11VEHICLE_CAN_CROSS\x10\x01\x12\x15\n\x11\x42ICYCLE_CAN_CROSS\x10\x02\x12\x13\n\x0fHUMAN_CAN_CROSS\x10\x03\x12\x11\n\rCAN_NOT_CROSS\x10\x04'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_id__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2.DESCRIPTOR,])



_OBJECT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='hdmap_lib.Object.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIDE_WALK', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHARGING_PILE', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEXT', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GROUND_SIGN', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS_STATION', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAFFIC_SIGN', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEIGHT_LIMIT_OBSTACLE', index=7, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUILDING', index=8, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DECELERATION_ZONE', index=9, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NON_SLIP_RAMP_MARKING', index=10, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIVERSION_LINE', index=11, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOCK_PAVILION', index=12, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REST_AREA', index=13, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WORKING_QUEUE_AREA', index=14, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHARGING_AREA', index=15, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRASS_GREEN_BELT', index=16, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEDESTRIAN_ISLAND', index=17, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMERGENCY_PARKING_ZONE', index=18, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FORBIDDEN_AREA', index=19, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLEAR_AREA', index=20, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANSITION', index=21, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBSTACLE', index=22, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUSH_GREEN_BELT', index=23, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRIDGE_EDGE', index=24, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=393,
  serialized_end=870,
)
_sym_db.RegisterEnumDescriptor(_OBJECT_TYPE)

_OBJECT_CROSSTYPE = _descriptor.EnumDescriptor(
  name='CrossType',
  full_name='hdmap_lib.Object.CrossType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VEHICLE_CAN_CROSS', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BICYCLE_CAN_CROSS', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HUMAN_CAN_CROSS', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAN_NOT_CROSS', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=872,
  serialized_end=969,
)
_sym_db.RegisterEnumDescriptor(_OBJECT_CROSSTYPE)


_OBJECT = _descriptor.Descriptor(
  name='Object',
  full_name='hdmap_lib.Object',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.Object.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='hdmap_lib.Object.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon', full_name='hdmap_lib.Object.polygon', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='hdmap_lib.Object.height', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='hdmap_lib.Object.text', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cross_type', full_name='hdmap_lib.Object.cross_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='hdmap_lib.Object.attributes', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OBJECT_TYPE,
    _OBJECT_CROSSTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=159,
  serialized_end=969,
)

_OBJECT.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_OBJECT.fields_by_name['type'].enum_type = _OBJECT_TYPE
_OBJECT.fields_by_name['polygon'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._POLYGON
_OBJECT.fields_by_name['cross_type'].enum_type = _OBJECT_CROSSTYPE
_OBJECT.fields_by_name['attributes'].message_type = proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2._ATTRIBUTE
_OBJECT_TYPE.containing_type = _OBJECT
_OBJECT_CROSSTYPE.containing_type = _OBJECT
DESCRIPTOR.message_types_by_name['Object'] = _OBJECT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Object = _reflection.GeneratedProtocolMessageType('Object', (_message.Message,), {
  'DESCRIPTOR' : _OBJECT,
  '__module__' : 'proto.hdmap_lib.proto.object_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.Object)
  })
_sym_db.RegisterMessage(Object)


# @@protoc_insertion_point(module_scope)
