# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/hdmap_lib/proto/lane.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import geometry_pb2 as proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2
from proto.hdmap_lib.proto import id_pb2 as proto_dot_hdmap__lib_dot_proto_dot_id__pb2
from proto.hdmap_lib.proto import attribute_pb2 as proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/hdmap_lib/proto/lane.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n proto/hdmap_lib/proto/lane.proto\x12\thdmap_lib\x1a$proto/hdmap_lib/proto/geometry.proto\x1a\x1eproto/hdmap_lib/proto/id.proto\x1a%proto/hdmap_lib/proto/attribute.proto\"\xc1\x0e\n\x04Lane\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12\"\n\x04type\x18\x02 \x01(\x0e\x32\x14.hdmap_lib.Lane.Type\x12+\n\x11left_lane_marking\x18\x03 \x01(\x0b\x32\x10.hdmap_lib.Curve\x12,\n\x12right_lane_marking\x18\x05 \x01(\x0b\x32\x10.hdmap_lib.Curve\x12+\n\tturn_type\x18\x07 \x01(\x0e\x32\x18.hdmap_lib.Lane.TurnType\x12-\n\nspeed_info\x18\x08 \x01(\x0b\x32\x19.hdmap_lib.Lane.SpeedInfo\x12\'\n\rcentral_curve\x18\t \x01(\x0b\x32\x10.hdmap_lib.Curve\x12\x0e\n\x06length\x18\n \x01(\x01\x12)\n\x12successor_lane_ids\x18\x0b \x03(\x0b\x32\r.hdmap_lib.Id\x12+\n\x14predecessor_lane_ids\x18\x0c \x03(\x0b\x32\r.hdmap_lib.Id\x12\x34\n\x1dleft_neighbor_forward_lane_id\x18\r \x01(\x0b\x32\r.hdmap_lib.Id\x12\x35\n\x1eright_neighbor_forward_lane_id\x18\x0e \x01(\x0b\x32\r.hdmap_lib.Id\x12\x35\n\x1eleft_neighbor_reverse_lane_ids\x18\x0f \x03(\x0b\x32\r.hdmap_lib.Id\x12\x36\n\x1fright_neighbor_reverse_lane_ids\x18\x10 \x03(\x0b\x32\r.hdmap_lib.Id\x12\"\n\x0bjunction_id\x18\x11 \x01(\x0b\x32\r.hdmap_lib.Id\x12\x13\n\x08priority\x18\x13 \x01(\x05:\x01\x30\x12(\n\nattributes\x18\x12 \x03(\x0b\x32\x14.hdmap_lib.Attribute\x12\x17\n\x0fis_waiting_area\x18\x14 \x01(\x08\x12\x17\n\x0fis_virtual_lane\x18\x19 \x01(\x08\x12\r\n\x05width\x18\x1a \x01(\x01\x12\x1e\n\x07road_id\x18\x1b \x01(\x0b\x32\r.hdmap_lib.Id\x12<\n%left_neighbor_forward_driving_lane_id\x18\x1c \x01(\x0b\x32\r.hdmap_lib.Id\x12=\n&right_neighbor_forward_driving_lane_id\x18\x1d \x01(\x0b\x32\r.hdmap_lib.Id\x12\x1a\n\x12lane_section_index\x18\x1e \x01(\x05\x12#\n\x07polygon\x18\x1f \x01(\x0b\x32\x12.hdmap_lib.Polygon\x1a<\n\tSpeedInfo\x12\x0e\n\x03min\x18\x01 \x01(\x01:\x01\x30\x12\x0f\n\x03max\x18\x02 \x01(\x01:\x02\x36\x30\x12\x0e\n\x06prefer\x18\x03 \x01(\x01\"\xbb\x03\n\x04Type\x12\x08\n\x04NONE\x10\x01\x12\x0b\n\x07\x44RIVING\x10\x02\x12\n\n\x06\x42IKING\x10\x03\x12\x0c\n\x08SHOULDER\x10\x04\x12\r\n\tEMERGENCY\x10\x05\x12\x07\n\x03\x42US\x10\x06\x12\x0e\n\nACCELERATE\x10\x07\x12\x0e\n\nDECELERATE\x10\x08\x12\x08\n\x04\x46\x41ST\x10\t\x12\x08\n\x04SLOW\x10\n\x12\x0f\n\x0bOVERTAKEING\x10\x0b\x12\n\n\x06\x45SCAPE\x10\x0c\x12\t\n\x05TIDAL\x10\r\x12\x12\n\x0eVARIABLE_GUIDE\x10\x0e\x12\x15\n\x11VER_TRUCK_DRIVING\x10\x0f\x12\x15\n\x11HOR_TRUCK_DRIVING\x10\x10\x12\x15\n\x11VER_HOR_EMERGENCY\x10\x11\x12\x12\n\x0eVER_HOR_EXPAND\x10\x12\x12\x16\n\x12YARD_TRUCK_DRIVING\x10\x13\x12\x16\n\x12\x44OCK_TRUCK_DRIVING\x10\x14\x12\t\n\x05\x43RANE\x10\x15\x12\n\n\x06GANTRY\x10\x16\x12\n\n\x06\x42RIDGE\x10\x17\x12\x10\n\x0cSHUTTLE_DOOR\x10\x18\x12\t\n\x05\x43HECK\x10\x19\x12\x0c\n\x08STACK_UP\x10\x1a\x12\n\n\x06GIRDER\x10\x1b\x12\x0c\n\x08\x42UNDLING\x10\x1c\x12\t\n\x05\x46LOOD\x10\x1d\"\xd7\x02\n\x08TurnType\x12\r\n\tNONE_TURN\x10\x01\x12\x0b\n\x07NO_TURN\x10\x02\x12\r\n\tLEFT_TURN\x10\x03\x12\x0e\n\nRIGHT_TURN\x10\x04\x12\n\n\x06U_TURN\x10\x05\x12\x12\n\x0eLEFT_TURN_WAIT\x10\x06\x12\x0f\n\x0bLEFT_U_TURN\x10\x07\x12\x10\n\x0cRIGHT_U_TURN\x10\x08\x12\x12\n\x0eSTRAIGHT_RIGHT\x10\t\x12\x11\n\rSTRAIGHT_LEFT\x10\n\x12\x0e\n\nLEFT_RIGHT\x10\x0b\x12\x17\n\x13LEFT_STRAIGHT_RIGHT\x10\x0c\x12\x19\n\x15RIGHT_STRAIGHT_U_TURN\x10\r\x12\x18\n\x14LEFT_STRAIGHT_U_TURN\x10\x0e\x12\x15\n\x11LEFT_RIGHT_U_TURN\x10\x0f\x12\x1e\n\x1aLEFT_STRAIGHT_RIGHT_U_TURN\x10\x10\x12\x11\n\rRIGHT_OBLIQUE\x10\x11'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_id__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2.DESCRIPTOR,])



_LANE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='hdmap_lib.Lane.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DRIVING', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BIKING', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHOULDER', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMERGENCY', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACCELERATE', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DECELERATE', index=7, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAST', index=8, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SLOW', index=9, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OVERTAKEING', index=10, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ESCAPE', index=11, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIDAL', index=12, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VARIABLE_GUIDE', index=13, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VER_TRUCK_DRIVING', index=14, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOR_TRUCK_DRIVING', index=15, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VER_HOR_EMERGENCY', index=16, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VER_HOR_EXPAND', index=17, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YARD_TRUCK_DRIVING', index=18, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOCK_TRUCK_DRIVING', index=19, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRANE', index=20, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GANTRY', index=21, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRIDGE', index=22, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHUTTLE_DOOR', index=23, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHECK', index=24, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STACK_UP', index=25, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GIRDER', index=26, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUNDLING', index=27, number=28,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLOOD', index=28, number=29,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1225,
  serialized_end=1668,
)
_sym_db.RegisterEnumDescriptor(_LANE_TYPE)

_LANE_TURNTYPE = _descriptor.EnumDescriptor(
  name='TurnType',
  full_name='hdmap_lib.Lane.TurnType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE_TURN', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_TURN', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_TURN', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_TURN', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='U_TURN', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_TURN_WAIT', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_U_TURN', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_U_TURN', index=7, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRAIGHT_RIGHT', index=8, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRAIGHT_LEFT', index=9, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_RIGHT', index=10, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_STRAIGHT_RIGHT', index=11, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_STRAIGHT_U_TURN', index=12, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_STRAIGHT_U_TURN', index=13, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_RIGHT_U_TURN', index=14, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_STRAIGHT_RIGHT_U_TURN', index=15, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_OBLIQUE', index=16, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1671,
  serialized_end=2014,
)
_sym_db.RegisterEnumDescriptor(_LANE_TURNTYPE)


_LANE_SPEEDINFO = _descriptor.Descriptor(
  name='SpeedInfo',
  full_name='hdmap_lib.Lane.SpeedInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min', full_name='hdmap_lib.Lane.SpeedInfo.min', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='hdmap_lib.Lane.SpeedInfo.max', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(60),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefer', full_name='hdmap_lib.Lane.SpeedInfo.prefer', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1162,
  serialized_end=1222,
)

_LANE = _descriptor.Descriptor(
  name='Lane',
  full_name='hdmap_lib.Lane',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.Lane.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='hdmap_lib.Lane.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_lane_marking', full_name='hdmap_lib.Lane.left_lane_marking', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_lane_marking', full_name='hdmap_lib.Lane.right_lane_marking', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='turn_type', full_name='hdmap_lib.Lane.turn_type', index=4,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_info', full_name='hdmap_lib.Lane.speed_info', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='central_curve', full_name='hdmap_lib.Lane.central_curve', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='hdmap_lib.Lane.length', index=7,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='successor_lane_ids', full_name='hdmap_lib.Lane.successor_lane_ids', index=8,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='predecessor_lane_ids', full_name='hdmap_lib.Lane.predecessor_lane_ids', index=9,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_neighbor_forward_lane_id', full_name='hdmap_lib.Lane.left_neighbor_forward_lane_id', index=10,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_neighbor_forward_lane_id', full_name='hdmap_lib.Lane.right_neighbor_forward_lane_id', index=11,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_neighbor_reverse_lane_ids', full_name='hdmap_lib.Lane.left_neighbor_reverse_lane_ids', index=12,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_neighbor_reverse_lane_ids', full_name='hdmap_lib.Lane.right_neighbor_reverse_lane_ids', index=13,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction_id', full_name='hdmap_lib.Lane.junction_id', index=14,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='hdmap_lib.Lane.priority', index=15,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='hdmap_lib.Lane.attributes', index=16,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_waiting_area', full_name='hdmap_lib.Lane.is_waiting_area', index=17,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_virtual_lane', full_name='hdmap_lib.Lane.is_virtual_lane', index=18,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='hdmap_lib.Lane.width', index=19,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='road_id', full_name='hdmap_lib.Lane.road_id', index=20,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_neighbor_forward_driving_lane_id', full_name='hdmap_lib.Lane.left_neighbor_forward_driving_lane_id', index=21,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_neighbor_forward_driving_lane_id', full_name='hdmap_lib.Lane.right_neighbor_forward_driving_lane_id', index=22,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_section_index', full_name='hdmap_lib.Lane.lane_section_index', index=23,
      number=30, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon', full_name='hdmap_lib.Lane.polygon', index=24,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LANE_SPEEDINFO, ],
  enum_types=[
    _LANE_TYPE,
    _LANE_TURNTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=2014,
)

_LANE_SPEEDINFO.containing_type = _LANE
_LANE.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LANE.fields_by_name['type'].enum_type = _LANE_TYPE
_LANE.fields_by_name['left_lane_marking'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._CURVE
_LANE.fields_by_name['right_lane_marking'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._CURVE
_LANE.fields_by_name['turn_type'].enum_type = _LANE_TURNTYPE
_LANE.fields_by_name['speed_info'].message_type = _LANE_SPEEDINFO
_LANE.fields_by_name['central_curve'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._CURVE
_LANE.fields_by_name['successor_lane_ids'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LANE.fields_by_name['predecessor_lane_ids'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LANE.fields_by_name['left_neighbor_forward_lane_id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LANE.fields_by_name['right_neighbor_forward_lane_id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LANE.fields_by_name['left_neighbor_reverse_lane_ids'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LANE.fields_by_name['right_neighbor_reverse_lane_ids'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LANE.fields_by_name['junction_id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LANE.fields_by_name['attributes'].message_type = proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2._ATTRIBUTE
_LANE.fields_by_name['road_id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LANE.fields_by_name['left_neighbor_forward_driving_lane_id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LANE.fields_by_name['right_neighbor_forward_driving_lane_id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LANE.fields_by_name['polygon'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._POLYGON
_LANE_TYPE.containing_type = _LANE
_LANE_TURNTYPE.containing_type = _LANE
DESCRIPTOR.message_types_by_name['Lane'] = _LANE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Lane = _reflection.GeneratedProtocolMessageType('Lane', (_message.Message,), {

  'SpeedInfo' : _reflection.GeneratedProtocolMessageType('SpeedInfo', (_message.Message,), {
    'DESCRIPTOR' : _LANE_SPEEDINFO,
    '__module__' : 'proto.hdmap_lib.proto.lane_pb2'
    # @@protoc_insertion_point(class_scope:hdmap_lib.Lane.SpeedInfo)
    })
  ,
  'DESCRIPTOR' : _LANE,
  '__module__' : 'proto.hdmap_lib.proto.lane_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.Lane)
  })
_sym_db.RegisterMessage(Lane)
_sym_db.RegisterMessage(Lane.SpeedInfo)


# @@protoc_insertion_point(module_scope)
