# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/hdmap_lib/proto/junction.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import geometry_pb2 as proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2
from proto.hdmap_lib.proto import id_pb2 as proto_dot_hdmap__lib_dot_proto_dot_id__pb2
from proto.hdmap_lib.proto import attribute_pb2 as proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/hdmap_lib/proto/junction.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$proto/hdmap_lib/proto/junction.proto\x12\thdmap_lib\x1a$proto/hdmap_lib/proto/geometry.proto\x1a\x1eproto/hdmap_lib/proto/id.proto\x1a%proto/hdmap_lib/proto/attribute.proto\"\xe5\x02\n\x08Junction\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12#\n\x07polygon\x18\x02 \x01(\x0b\x32\x12.hdmap_lib.Polygon\x12(\n\nattributes\x18\x03 \x03(\x0b\x32\x14.hdmap_lib.Attribute\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x1b\n\x13is_virtual_junction\x18\x05 \x01(\x08\x12&\n\x04type\x18\x06 \x01(\x0e\x32\x18.hdmap_lib.Junction.Type\x12\x1f\n\x08road_ids\x18\x07 \x03(\x0b\x32\r.hdmap_lib.Id\"{\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0e\n\nT_JUNCTION\x10\x02\x12\x0e\n\nY_JUNCTION\x10\x03\x12\x0e\n\nX_JUNCTION\x10\x06\x12\x1c\n\x18\x42RIDGE_ENTRANCE_JUNCTION\x10\x08\x12\x18\n\x14\x42RIDGE_EXIT_JUNCTION\x10\t'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_id__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2.DESCRIPTOR,])



_JUNCTION_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='hdmap_lib.Junction.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='T_JUNCTION', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Y_JUNCTION', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='X_JUNCTION', index=3, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRIDGE_ENTRANCE_JUNCTION', index=4, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRIDGE_EXIT_JUNCTION', index=5, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=395,
  serialized_end=518,
)
_sym_db.RegisterEnumDescriptor(_JUNCTION_TYPE)


_JUNCTION = _descriptor.Descriptor(
  name='Junction',
  full_name='hdmap_lib.Junction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.Junction.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon', full_name='hdmap_lib.Junction.polygon', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='hdmap_lib.Junction.attributes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='hdmap_lib.Junction.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_virtual_junction', full_name='hdmap_lib.Junction.is_virtual_junction', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='hdmap_lib.Junction.type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='road_ids', full_name='hdmap_lib.Junction.road_ids', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _JUNCTION_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=161,
  serialized_end=518,
)

_JUNCTION.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_JUNCTION.fields_by_name['polygon'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._POLYGON
_JUNCTION.fields_by_name['attributes'].message_type = proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2._ATTRIBUTE
_JUNCTION.fields_by_name['type'].enum_type = _JUNCTION_TYPE
_JUNCTION.fields_by_name['road_ids'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_JUNCTION_TYPE.containing_type = _JUNCTION
DESCRIPTOR.message_types_by_name['Junction'] = _JUNCTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Junction = _reflection.GeneratedProtocolMessageType('Junction', (_message.Message,), {
  'DESCRIPTOR' : _JUNCTION,
  '__module__' : 'proto.hdmap_lib.proto.junction_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.Junction)
  })
_sym_db.RegisterMessage(Junction)


# @@protoc_insertion_point(module_scope)
