# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/hdmap_lib/proto/parking_space.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import id_pb2 as proto_dot_hdmap__lib_dot_proto_dot_id__pb2
from proto.hdmap_lib.proto import geometry_pb2 as proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/hdmap_lib/proto/parking_space.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)proto/hdmap_lib/proto/parking_space.proto\x12\thdmap_lib\x1a\x1eproto/hdmap_lib/proto/id.proto\x1a$proto/hdmap_lib/proto/geometry.proto\"\xe8\x02\n\x0cParkingSpace\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12\'\n\rleft_boundary\x18\x02 \x01(\x0b\x32\x10.hdmap_lib.Curve\x12(\n\x0eright_boundary\x18\x03 \x01(\x0b\x32\x10.hdmap_lib.Curve\x12\'\n\rcentral_curve\x18\x06 \x01(\x0b\x32\x10.hdmap_lib.Curve\x12\x33\n\x08in_lanes\x18\x04 \x03(\x0b\x32!.hdmap_lib.ParkingSpace.LanePoint\x12\x34\n\tout_lanes\x18\x05 \x03(\x0b\x32!.hdmap_lib.ParkingSpace.LanePoint\x12#\n\x07polygon\x18\x07 \x01(\x0b\x32\x12.hdmap_lib.Polygon\x1a\x31\n\tLanePoint\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12\t\n\x01s\x18\x02 \x01(\x01\"v\n\x0ePullOverRegion\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12\x1e\n\x07lane_id\x18\x02 \x01(\x0b\x32\r.hdmap_lib.Id\x12\x0f\n\x07start_s\x18\x03 \x01(\x01\x12\r\n\x05\x65nd_s\x18\x04 \x01(\x01\x12\t\n\x01\x64\x18\x05 \x01(\x01'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_id__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2.DESCRIPTOR,])




_PARKINGSPACE_LANEPOINT = _descriptor.Descriptor(
  name='LanePoint',
  full_name='hdmap_lib.ParkingSpace.LanePoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.ParkingSpace.LanePoint.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s', full_name='hdmap_lib.ParkingSpace.LanePoint.s', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=438,
  serialized_end=487,
)

_PARKINGSPACE = _descriptor.Descriptor(
  name='ParkingSpace',
  full_name='hdmap_lib.ParkingSpace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.ParkingSpace.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_boundary', full_name='hdmap_lib.ParkingSpace.left_boundary', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_boundary', full_name='hdmap_lib.ParkingSpace.right_boundary', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='central_curve', full_name='hdmap_lib.ParkingSpace.central_curve', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_lanes', full_name='hdmap_lib.ParkingSpace.in_lanes', index=4,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='out_lanes', full_name='hdmap_lib.ParkingSpace.out_lanes', index=5,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon', full_name='hdmap_lib.ParkingSpace.polygon', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PARKINGSPACE_LANEPOINT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=127,
  serialized_end=487,
)


_PULLOVERREGION = _descriptor.Descriptor(
  name='PullOverRegion',
  full_name='hdmap_lib.PullOverRegion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.PullOverRegion.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='hdmap_lib.PullOverRegion.lane_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_s', full_name='hdmap_lib.PullOverRegion.start_s', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_s', full_name='hdmap_lib.PullOverRegion.end_s', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='d', full_name='hdmap_lib.PullOverRegion.d', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=489,
  serialized_end=607,
)

_PARKINGSPACE_LANEPOINT.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_PARKINGSPACE_LANEPOINT.containing_type = _PARKINGSPACE
_PARKINGSPACE.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_PARKINGSPACE.fields_by_name['left_boundary'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._CURVE
_PARKINGSPACE.fields_by_name['right_boundary'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._CURVE
_PARKINGSPACE.fields_by_name['central_curve'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._CURVE
_PARKINGSPACE.fields_by_name['in_lanes'].message_type = _PARKINGSPACE_LANEPOINT
_PARKINGSPACE.fields_by_name['out_lanes'].message_type = _PARKINGSPACE_LANEPOINT
_PARKINGSPACE.fields_by_name['polygon'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._POLYGON
_PULLOVERREGION.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_PULLOVERREGION.fields_by_name['lane_id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
DESCRIPTOR.message_types_by_name['ParkingSpace'] = _PARKINGSPACE
DESCRIPTOR.message_types_by_name['PullOverRegion'] = _PULLOVERREGION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ParkingSpace = _reflection.GeneratedProtocolMessageType('ParkingSpace', (_message.Message,), {

  'LanePoint' : _reflection.GeneratedProtocolMessageType('LanePoint', (_message.Message,), {
    'DESCRIPTOR' : _PARKINGSPACE_LANEPOINT,
    '__module__' : 'proto.hdmap_lib.proto.parking_space_pb2'
    # @@protoc_insertion_point(class_scope:hdmap_lib.ParkingSpace.LanePoint)
    })
  ,
  'DESCRIPTOR' : _PARKINGSPACE,
  '__module__' : 'proto.hdmap_lib.proto.parking_space_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.ParkingSpace)
  })
_sym_db.RegisterMessage(ParkingSpace)
_sym_db.RegisterMessage(ParkingSpace.LanePoint)

PullOverRegion = _reflection.GeneratedProtocolMessageType('PullOverRegion', (_message.Message,), {
  'DESCRIPTOR' : _PULLOVERREGION,
  '__module__' : 'proto.hdmap_lib.proto.parking_space_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.PullOverRegion)
  })
_sym_db.RegisterMessage(PullOverRegion)


# @@protoc_insertion_point(module_scope)
