# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/hdmap_lib/proto/relation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import id_pb2 as proto_dot_hdmap__lib_dot_proto_dot_id__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/hdmap_lib/proto/relation.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$proto/hdmap_lib/proto/relation.proto\x12\thdmap_lib\x1a\x1eproto/hdmap_lib/proto/id.proto\"1\n\x0fLaneOverlapInfo\x12\x0f\n\x07start_s\x18\x01 \x01(\x01\x12\r\n\x05\x65nd_s\x18\x02 \x01(\x01\"p\n\x12ObjectRelationInfo\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12\x37\n\x11lane_overlap_info\x18\x02 \x01(\x0b\x32\x1a.hdmap_lib.LaneOverlapInfoH\x00\x42\x06\n\x04info\"w\n\x0fLaneLaneOverlap\x12/\n\x08one_lane\x18\x01 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\x12\x33\n\x0c\x61nother_lane\x18\x02 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\"u\n\x14LaneCrosswalkOverlap\x12+\n\x04lane\x18\x01 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\x12\x30\n\tcrosswalk\x18\x02 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\"t\n\x13LaneStopLineOverlap\x12+\n\x04lane\x18\x01 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\x12\x30\n\tstop_line\x18\x02 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\"v\n\x14LaneClearAreaOverlap\x12+\n\x04lane\x18\x01 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\x12\x31\n\nclear_area\x18\x02 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\"s\n\x13LaneJunctionOverlap\x12+\n\x04lane\x18\x01 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\x12/\n\x08junction\x18\x02 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\"\x85\x01\n\x1bTrafficLightStopLineOverlap\x12\x34\n\rtraffic_light\x18\x01 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\x12\x30\n\tstop_line\x18\x02 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\"\x80\x01\n\x19PoiPullOverRegionRelation\x12*\n\x03poi\x18\x01 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\x12\x37\n\x10pull_over_region\x18\x02 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\"{\n\x17PoiParkingSpaceRelation\x12*\n\x03poi\x18\x01 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\x12\x34\n\rparking_space\x18\x02 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\"\x82\x01\n\x1aLanePullOverRegionRelation\x12+\n\x04lane\x18\x01 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\x12\x37\n\x10pull_over_region\x18\x02 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\"j\n\x0fLanePoiRelation\x12+\n\x04lane\x18\x01 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\x12*\n\x03poi\x18\x02 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\"o\n\x11LaneObjectOverlap\x12+\n\x04lane\x18\x01 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\x12-\n\x06object\x18\x02 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\"\x83\x08\n\x08Relation\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12.\n\x04type\x18\x02 \x01(\x0e\x32 .hdmap_lib.Relation.RelationType\x12<\n\x16lane_lane_overlap_info\x18\x06 \x01(\x0b\x32\x1a.hdmap_lib.LaneLaneOverlapH\x00\x12\x46\n\x1blane_crosswalk_overlap_info\x18\x03 \x01(\x0b\x32\x1f.hdmap_lib.LaneCrosswalkOverlapH\x00\x12\x45\n\x1blane_stop_line_overlap_info\x18\x04 \x01(\x0b\x32\x1e.hdmap_lib.LaneStopLineOverlapH\x00\x12L\n\x1atraffic_light_overlap_info\x18\x05 \x01(\x0b\x32&.hdmap_lib.TrafficLightStopLineOverlapH\x00\x12R\n\"poi_pull_over_region_relation_info\x18\x07 \x01(\x0b\x32$.hdmap_lib.PoiPullOverRegionRelationH\x00\x12M\n\x1fpoi_parking_space_relation_info\x18\x0b \x01(\x0b\x32\".hdmap_lib.PoiParkingSpaceRelationH\x00\x12<\n\x16lane_poi_relation_info\x18\t \x01(\x0b\x32\x1a.hdmap_lib.LanePoiRelationH\x00\x12@\n\x18lane_object_overlap_info\x18\x0c \x01(\x0b\x32\x1c.hdmap_lib.LaneObjectOverlapH\x00\x12\x44\n\x1alane_junction_overlap_info\x18\r \x01(\x0b\x32\x1e.hdmap_lib.LaneJunctionOverlapH\x00\"\x96\x02\n\x0cRelationType\x12\x16\n\x12RELATION_LANE_LANE\x10\x01\x12\x1b\n\x17RELATION_LANE_CROSSWALK\x10\x02\x12\x1b\n\x17RELATION_LANE_STOP_LINE\x10\x03\x12$\n RELATION_TRAFFIC_LIGHT_STOP_LINE\x10\x04\x12!\n\x1dRELATION_POI_PULL_OVER_REGION\x10\x05\x12\x1e\n\x1aRELATION_POI_PARKING_SPACE\x10\x08\x12\x15\n\x11RELATION_LANE_POI\x10\x06\x12\x18\n\x14RELATION_LANE_OBJECT\x10\t\x12\x1a\n\x16RELATION_LANE_JUNCTION\x10\nB\x0f\n\rrelation_info'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_id__pb2.DESCRIPTOR,])



_RELATION_RELATIONTYPE = _descriptor.EnumDescriptor(
  name='RelationType',
  full_name='hdmap_lib.Relation.RelationType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RELATION_LANE_LANE', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELATION_LANE_CROSSWALK', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELATION_LANE_STOP_LINE', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELATION_TRAFFIC_LIGHT_STOP_LINE', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELATION_POI_PULL_OVER_REGION', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELATION_POI_PARKING_SPACE', index=5, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELATION_LANE_POI', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELATION_LANE_OBJECT', index=7, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELATION_LANE_JUNCTION', index=8, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2322,
  serialized_end=2600,
)
_sym_db.RegisterEnumDescriptor(_RELATION_RELATIONTYPE)


_LANEOVERLAPINFO = _descriptor.Descriptor(
  name='LaneOverlapInfo',
  full_name='hdmap_lib.LaneOverlapInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_s', full_name='hdmap_lib.LaneOverlapInfo.start_s', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_s', full_name='hdmap_lib.LaneOverlapInfo.end_s', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=132,
)


_OBJECTRELATIONINFO = _descriptor.Descriptor(
  name='ObjectRelationInfo',
  full_name='hdmap_lib.ObjectRelationInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.ObjectRelationInfo.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_overlap_info', full_name='hdmap_lib.ObjectRelationInfo.lane_overlap_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='info', full_name='hdmap_lib.ObjectRelationInfo.info',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=134,
  serialized_end=246,
)


_LANELANEOVERLAP = _descriptor.Descriptor(
  name='LaneLaneOverlap',
  full_name='hdmap_lib.LaneLaneOverlap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='one_lane', full_name='hdmap_lib.LaneLaneOverlap.one_lane', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='another_lane', full_name='hdmap_lib.LaneLaneOverlap.another_lane', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=248,
  serialized_end=367,
)


_LANECROSSWALKOVERLAP = _descriptor.Descriptor(
  name='LaneCrosswalkOverlap',
  full_name='hdmap_lib.LaneCrosswalkOverlap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane', full_name='hdmap_lib.LaneCrosswalkOverlap.lane', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crosswalk', full_name='hdmap_lib.LaneCrosswalkOverlap.crosswalk', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=369,
  serialized_end=486,
)


_LANESTOPLINEOVERLAP = _descriptor.Descriptor(
  name='LaneStopLineOverlap',
  full_name='hdmap_lib.LaneStopLineOverlap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane', full_name='hdmap_lib.LaneStopLineOverlap.lane', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_line', full_name='hdmap_lib.LaneStopLineOverlap.stop_line', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=488,
  serialized_end=604,
)


_LANECLEARAREAOVERLAP = _descriptor.Descriptor(
  name='LaneClearAreaOverlap',
  full_name='hdmap_lib.LaneClearAreaOverlap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane', full_name='hdmap_lib.LaneClearAreaOverlap.lane', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_area', full_name='hdmap_lib.LaneClearAreaOverlap.clear_area', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=606,
  serialized_end=724,
)


_LANEJUNCTIONOVERLAP = _descriptor.Descriptor(
  name='LaneJunctionOverlap',
  full_name='hdmap_lib.LaneJunctionOverlap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane', full_name='hdmap_lib.LaneJunctionOverlap.lane', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction', full_name='hdmap_lib.LaneJunctionOverlap.junction', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=726,
  serialized_end=841,
)


_TRAFFICLIGHTSTOPLINEOVERLAP = _descriptor.Descriptor(
  name='TrafficLightStopLineOverlap',
  full_name='hdmap_lib.TrafficLightStopLineOverlap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='traffic_light', full_name='hdmap_lib.TrafficLightStopLineOverlap.traffic_light', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_line', full_name='hdmap_lib.TrafficLightStopLineOverlap.stop_line', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=844,
  serialized_end=977,
)


_POIPULLOVERREGIONRELATION = _descriptor.Descriptor(
  name='PoiPullOverRegionRelation',
  full_name='hdmap_lib.PoiPullOverRegionRelation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='poi', full_name='hdmap_lib.PoiPullOverRegionRelation.poi', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pull_over_region', full_name='hdmap_lib.PoiPullOverRegionRelation.pull_over_region', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=980,
  serialized_end=1108,
)


_POIPARKINGSPACERELATION = _descriptor.Descriptor(
  name='PoiParkingSpaceRelation',
  full_name='hdmap_lib.PoiParkingSpaceRelation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='poi', full_name='hdmap_lib.PoiParkingSpaceRelation.poi', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_space', full_name='hdmap_lib.PoiParkingSpaceRelation.parking_space', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1110,
  serialized_end=1233,
)


_LANEPULLOVERREGIONRELATION = _descriptor.Descriptor(
  name='LanePullOverRegionRelation',
  full_name='hdmap_lib.LanePullOverRegionRelation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane', full_name='hdmap_lib.LanePullOverRegionRelation.lane', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pull_over_region', full_name='hdmap_lib.LanePullOverRegionRelation.pull_over_region', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1236,
  serialized_end=1366,
)


_LANEPOIRELATION = _descriptor.Descriptor(
  name='LanePoiRelation',
  full_name='hdmap_lib.LanePoiRelation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane', full_name='hdmap_lib.LanePoiRelation.lane', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='poi', full_name='hdmap_lib.LanePoiRelation.poi', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1368,
  serialized_end=1474,
)


_LANEOBJECTOVERLAP = _descriptor.Descriptor(
  name='LaneObjectOverlap',
  full_name='hdmap_lib.LaneObjectOverlap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane', full_name='hdmap_lib.LaneObjectOverlap.lane', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object', full_name='hdmap_lib.LaneObjectOverlap.object', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1476,
  serialized_end=1587,
)


_RELATION = _descriptor.Descriptor(
  name='Relation',
  full_name='hdmap_lib.Relation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.Relation.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='hdmap_lib.Relation.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_lane_overlap_info', full_name='hdmap_lib.Relation.lane_lane_overlap_info', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_crosswalk_overlap_info', full_name='hdmap_lib.Relation.lane_crosswalk_overlap_info', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_stop_line_overlap_info', full_name='hdmap_lib.Relation.lane_stop_line_overlap_info', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_light_overlap_info', full_name='hdmap_lib.Relation.traffic_light_overlap_info', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='poi_pull_over_region_relation_info', full_name='hdmap_lib.Relation.poi_pull_over_region_relation_info', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='poi_parking_space_relation_info', full_name='hdmap_lib.Relation.poi_parking_space_relation_info', index=7,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_poi_relation_info', full_name='hdmap_lib.Relation.lane_poi_relation_info', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_object_overlap_info', full_name='hdmap_lib.Relation.lane_object_overlap_info', index=9,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_junction_overlap_info', full_name='hdmap_lib.Relation.lane_junction_overlap_info', index=10,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RELATION_RELATIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='relation_info', full_name='hdmap_lib.Relation.relation_info',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1590,
  serialized_end=2617,
)

_OBJECTRELATIONINFO.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_OBJECTRELATIONINFO.fields_by_name['lane_overlap_info'].message_type = _LANEOVERLAPINFO
_OBJECTRELATIONINFO.oneofs_by_name['info'].fields.append(
  _OBJECTRELATIONINFO.fields_by_name['lane_overlap_info'])
_OBJECTRELATIONINFO.fields_by_name['lane_overlap_info'].containing_oneof = _OBJECTRELATIONINFO.oneofs_by_name['info']
_LANELANEOVERLAP.fields_by_name['one_lane'].message_type = _OBJECTRELATIONINFO
_LANELANEOVERLAP.fields_by_name['another_lane'].message_type = _OBJECTRELATIONINFO
_LANECROSSWALKOVERLAP.fields_by_name['lane'].message_type = _OBJECTRELATIONINFO
_LANECROSSWALKOVERLAP.fields_by_name['crosswalk'].message_type = _OBJECTRELATIONINFO
_LANESTOPLINEOVERLAP.fields_by_name['lane'].message_type = _OBJECTRELATIONINFO
_LANESTOPLINEOVERLAP.fields_by_name['stop_line'].message_type = _OBJECTRELATIONINFO
_LANECLEARAREAOVERLAP.fields_by_name['lane'].message_type = _OBJECTRELATIONINFO
_LANECLEARAREAOVERLAP.fields_by_name['clear_area'].message_type = _OBJECTRELATIONINFO
_LANEJUNCTIONOVERLAP.fields_by_name['lane'].message_type = _OBJECTRELATIONINFO
_LANEJUNCTIONOVERLAP.fields_by_name['junction'].message_type = _OBJECTRELATIONINFO
_TRAFFICLIGHTSTOPLINEOVERLAP.fields_by_name['traffic_light'].message_type = _OBJECTRELATIONINFO
_TRAFFICLIGHTSTOPLINEOVERLAP.fields_by_name['stop_line'].message_type = _OBJECTRELATIONINFO
_POIPULLOVERREGIONRELATION.fields_by_name['poi'].message_type = _OBJECTRELATIONINFO
_POIPULLOVERREGIONRELATION.fields_by_name['pull_over_region'].message_type = _OBJECTRELATIONINFO
_POIPARKINGSPACERELATION.fields_by_name['poi'].message_type = _OBJECTRELATIONINFO
_POIPARKINGSPACERELATION.fields_by_name['parking_space'].message_type = _OBJECTRELATIONINFO
_LANEPULLOVERREGIONRELATION.fields_by_name['lane'].message_type = _OBJECTRELATIONINFO
_LANEPULLOVERREGIONRELATION.fields_by_name['pull_over_region'].message_type = _OBJECTRELATIONINFO
_LANEPOIRELATION.fields_by_name['lane'].message_type = _OBJECTRELATIONINFO
_LANEPOIRELATION.fields_by_name['poi'].message_type = _OBJECTRELATIONINFO
_LANEOBJECTOVERLAP.fields_by_name['lane'].message_type = _OBJECTRELATIONINFO
_LANEOBJECTOVERLAP.fields_by_name['object'].message_type = _OBJECTRELATIONINFO
_RELATION.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_RELATION.fields_by_name['type'].enum_type = _RELATION_RELATIONTYPE
_RELATION.fields_by_name['lane_lane_overlap_info'].message_type = _LANELANEOVERLAP
_RELATION.fields_by_name['lane_crosswalk_overlap_info'].message_type = _LANECROSSWALKOVERLAP
_RELATION.fields_by_name['lane_stop_line_overlap_info'].message_type = _LANESTOPLINEOVERLAP
_RELATION.fields_by_name['traffic_light_overlap_info'].message_type = _TRAFFICLIGHTSTOPLINEOVERLAP
_RELATION.fields_by_name['poi_pull_over_region_relation_info'].message_type = _POIPULLOVERREGIONRELATION
_RELATION.fields_by_name['poi_parking_space_relation_info'].message_type = _POIPARKINGSPACERELATION
_RELATION.fields_by_name['lane_poi_relation_info'].message_type = _LANEPOIRELATION
_RELATION.fields_by_name['lane_object_overlap_info'].message_type = _LANEOBJECTOVERLAP
_RELATION.fields_by_name['lane_junction_overlap_info'].message_type = _LANEJUNCTIONOVERLAP
_RELATION_RELATIONTYPE.containing_type = _RELATION
_RELATION.oneofs_by_name['relation_info'].fields.append(
  _RELATION.fields_by_name['lane_lane_overlap_info'])
_RELATION.fields_by_name['lane_lane_overlap_info'].containing_oneof = _RELATION.oneofs_by_name['relation_info']
_RELATION.oneofs_by_name['relation_info'].fields.append(
  _RELATION.fields_by_name['lane_crosswalk_overlap_info'])
_RELATION.fields_by_name['lane_crosswalk_overlap_info'].containing_oneof = _RELATION.oneofs_by_name['relation_info']
_RELATION.oneofs_by_name['relation_info'].fields.append(
  _RELATION.fields_by_name['lane_stop_line_overlap_info'])
_RELATION.fields_by_name['lane_stop_line_overlap_info'].containing_oneof = _RELATION.oneofs_by_name['relation_info']
_RELATION.oneofs_by_name['relation_info'].fields.append(
  _RELATION.fields_by_name['traffic_light_overlap_info'])
_RELATION.fields_by_name['traffic_light_overlap_info'].containing_oneof = _RELATION.oneofs_by_name['relation_info']
_RELATION.oneofs_by_name['relation_info'].fields.append(
  _RELATION.fields_by_name['poi_pull_over_region_relation_info'])
_RELATION.fields_by_name['poi_pull_over_region_relation_info'].containing_oneof = _RELATION.oneofs_by_name['relation_info']
_RELATION.oneofs_by_name['relation_info'].fields.append(
  _RELATION.fields_by_name['poi_parking_space_relation_info'])
_RELATION.fields_by_name['poi_parking_space_relation_info'].containing_oneof = _RELATION.oneofs_by_name['relation_info']
_RELATION.oneofs_by_name['relation_info'].fields.append(
  _RELATION.fields_by_name['lane_poi_relation_info'])
_RELATION.fields_by_name['lane_poi_relation_info'].containing_oneof = _RELATION.oneofs_by_name['relation_info']
_RELATION.oneofs_by_name['relation_info'].fields.append(
  _RELATION.fields_by_name['lane_object_overlap_info'])
_RELATION.fields_by_name['lane_object_overlap_info'].containing_oneof = _RELATION.oneofs_by_name['relation_info']
_RELATION.oneofs_by_name['relation_info'].fields.append(
  _RELATION.fields_by_name['lane_junction_overlap_info'])
_RELATION.fields_by_name['lane_junction_overlap_info'].containing_oneof = _RELATION.oneofs_by_name['relation_info']
DESCRIPTOR.message_types_by_name['LaneOverlapInfo'] = _LANEOVERLAPINFO
DESCRIPTOR.message_types_by_name['ObjectRelationInfo'] = _OBJECTRELATIONINFO
DESCRIPTOR.message_types_by_name['LaneLaneOverlap'] = _LANELANEOVERLAP
DESCRIPTOR.message_types_by_name['LaneCrosswalkOverlap'] = _LANECROSSWALKOVERLAP
DESCRIPTOR.message_types_by_name['LaneStopLineOverlap'] = _LANESTOPLINEOVERLAP
DESCRIPTOR.message_types_by_name['LaneClearAreaOverlap'] = _LANECLEARAREAOVERLAP
DESCRIPTOR.message_types_by_name['LaneJunctionOverlap'] = _LANEJUNCTIONOVERLAP
DESCRIPTOR.message_types_by_name['TrafficLightStopLineOverlap'] = _TRAFFICLIGHTSTOPLINEOVERLAP
DESCRIPTOR.message_types_by_name['PoiPullOverRegionRelation'] = _POIPULLOVERREGIONRELATION
DESCRIPTOR.message_types_by_name['PoiParkingSpaceRelation'] = _POIPARKINGSPACERELATION
DESCRIPTOR.message_types_by_name['LanePullOverRegionRelation'] = _LANEPULLOVERREGIONRELATION
DESCRIPTOR.message_types_by_name['LanePoiRelation'] = _LANEPOIRELATION
DESCRIPTOR.message_types_by_name['LaneObjectOverlap'] = _LANEOBJECTOVERLAP
DESCRIPTOR.message_types_by_name['Relation'] = _RELATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LaneOverlapInfo = _reflection.GeneratedProtocolMessageType('LaneOverlapInfo', (_message.Message,), {
  'DESCRIPTOR' : _LANEOVERLAPINFO,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LaneOverlapInfo)
  })
_sym_db.RegisterMessage(LaneOverlapInfo)

ObjectRelationInfo = _reflection.GeneratedProtocolMessageType('ObjectRelationInfo', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTRELATIONINFO,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.ObjectRelationInfo)
  })
_sym_db.RegisterMessage(ObjectRelationInfo)

LaneLaneOverlap = _reflection.GeneratedProtocolMessageType('LaneLaneOverlap', (_message.Message,), {
  'DESCRIPTOR' : _LANELANEOVERLAP,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LaneLaneOverlap)
  })
_sym_db.RegisterMessage(LaneLaneOverlap)

LaneCrosswalkOverlap = _reflection.GeneratedProtocolMessageType('LaneCrosswalkOverlap', (_message.Message,), {
  'DESCRIPTOR' : _LANECROSSWALKOVERLAP,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LaneCrosswalkOverlap)
  })
_sym_db.RegisterMessage(LaneCrosswalkOverlap)

LaneStopLineOverlap = _reflection.GeneratedProtocolMessageType('LaneStopLineOverlap', (_message.Message,), {
  'DESCRIPTOR' : _LANESTOPLINEOVERLAP,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LaneStopLineOverlap)
  })
_sym_db.RegisterMessage(LaneStopLineOverlap)

LaneClearAreaOverlap = _reflection.GeneratedProtocolMessageType('LaneClearAreaOverlap', (_message.Message,), {
  'DESCRIPTOR' : _LANECLEARAREAOVERLAP,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LaneClearAreaOverlap)
  })
_sym_db.RegisterMessage(LaneClearAreaOverlap)

LaneJunctionOverlap = _reflection.GeneratedProtocolMessageType('LaneJunctionOverlap', (_message.Message,), {
  'DESCRIPTOR' : _LANEJUNCTIONOVERLAP,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LaneJunctionOverlap)
  })
_sym_db.RegisterMessage(LaneJunctionOverlap)

TrafficLightStopLineOverlap = _reflection.GeneratedProtocolMessageType('TrafficLightStopLineOverlap', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICLIGHTSTOPLINEOVERLAP,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.TrafficLightStopLineOverlap)
  })
_sym_db.RegisterMessage(TrafficLightStopLineOverlap)

PoiPullOverRegionRelation = _reflection.GeneratedProtocolMessageType('PoiPullOverRegionRelation', (_message.Message,), {
  'DESCRIPTOR' : _POIPULLOVERREGIONRELATION,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.PoiPullOverRegionRelation)
  })
_sym_db.RegisterMessage(PoiPullOverRegionRelation)

PoiParkingSpaceRelation = _reflection.GeneratedProtocolMessageType('PoiParkingSpaceRelation', (_message.Message,), {
  'DESCRIPTOR' : _POIPARKINGSPACERELATION,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.PoiParkingSpaceRelation)
  })
_sym_db.RegisterMessage(PoiParkingSpaceRelation)

LanePullOverRegionRelation = _reflection.GeneratedProtocolMessageType('LanePullOverRegionRelation', (_message.Message,), {
  'DESCRIPTOR' : _LANEPULLOVERREGIONRELATION,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LanePullOverRegionRelation)
  })
_sym_db.RegisterMessage(LanePullOverRegionRelation)

LanePoiRelation = _reflection.GeneratedProtocolMessageType('LanePoiRelation', (_message.Message,), {
  'DESCRIPTOR' : _LANEPOIRELATION,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LanePoiRelation)
  })
_sym_db.RegisterMessage(LanePoiRelation)

LaneObjectOverlap = _reflection.GeneratedProtocolMessageType('LaneObjectOverlap', (_message.Message,), {
  'DESCRIPTOR' : _LANEOBJECTOVERLAP,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LaneObjectOverlap)
  })
_sym_db.RegisterMessage(LaneObjectOverlap)

Relation = _reflection.GeneratedProtocolMessageType('Relation', (_message.Message,), {
  'DESCRIPTOR' : _RELATION,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.Relation)
  })
_sym_db.RegisterMessage(Relation)


# @@protoc_insertion_point(module_scope)
