# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/hdmap_lib/proto/poi.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import id_pb2 as proto_dot_hdmap__lib_dot_proto_dot_id__pb2
from proto.hdmap_lib.proto import geometry_pb2 as proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/hdmap_lib/proto/poi.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fproto/hdmap_lib/proto/poi.proto\x12\thdmap_lib\x1a\x1eproto/hdmap_lib/proto/id.proto\x1a$proto/hdmap_lib/proto/geometry.proto\"\xa4\x02\n\x03Poi\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12\x0c\n\x04name\x18\x02 \x01(\t\x12$\n\x04type\x18\x03 \x01(\x0e\x32\x16.hdmap_lib.Poi.PoiType\x12&\n\ncoordinate\x18\x04 \x01(\x0b\x32\x12.hdmap_lib.Point3D\"\xa5\x01\n\x07PoiType\x12\x14\n\x10POI_QUEUE_REGION\x10\x01\x12\x13\n\x0fPOI_REST_REGION\x10\x02\x12\x15\n\x11POI_CHARGE_REGION\x10\x03\x12\x13\n\x0fPOI_LOCK_REGION\x10\x04\x12\x15\n\x11POI_UNLOCK_REGION\x10\x05\x12\x14\n\x10POI_LEAVE_REGION\x10\x06\x12\x16\n\x12POI_OFFLINE_REGION\x10\x07'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_id__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2.DESCRIPTOR,])



_POI_POITYPE = _descriptor.EnumDescriptor(
  name='PoiType',
  full_name='hdmap_lib.Poi.PoiType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='POI_QUEUE_REGION', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POI_REST_REGION', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POI_CHARGE_REGION', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POI_LOCK_REGION', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POI_UNLOCK_REGION', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POI_LEAVE_REGION', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POI_OFFLINE_REGION', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=244,
  serialized_end=409,
)
_sym_db.RegisterEnumDescriptor(_POI_POITYPE)


_POI = _descriptor.Descriptor(
  name='Poi',
  full_name='hdmap_lib.Poi',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.Poi.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='hdmap_lib.Poi.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='hdmap_lib.Poi.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='coordinate', full_name='hdmap_lib.Poi.coordinate', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _POI_POITYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=409,
)

_POI.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_POI.fields_by_name['type'].enum_type = _POI_POITYPE
_POI.fields_by_name['coordinate'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._POINT3D
_POI_POITYPE.containing_type = _POI
DESCRIPTOR.message_types_by_name['Poi'] = _POI
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Poi = _reflection.GeneratedProtocolMessageType('Poi', (_message.Message,), {
  'DESCRIPTOR' : _POI,
  '__module__' : 'proto.hdmap_lib.proto.poi_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.Poi)
  })
_sym_db.RegisterMessage(Poi)


# @@protoc_insertion_point(module_scope)
