# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/hdmap_lib/proto/geometry.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import id_pb2 as proto_dot_hdmap__lib_dot_proto_dot_id__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/hdmap_lib/proto/geometry.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$proto/hdmap_lib/proto/geometry.proto\x12\thdmap_lib\x1a\x1eproto/hdmap_lib/proto/id.proto\"-\n\x07Point3D\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\x0c\n\x01z\x18\x03 \x01(\x01:\x01\x30\"\xd9\x02\n\x0eLineStringData\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12.\n\x05\x63olor\x18\x02 \x01(\x0e\x32\x1f.hdmap_lib.LineStringData.Color\x12,\n\x04type\x18\x03 \x01(\x0e\x32\x1e.hdmap_lib.LineStringData.Type\x12\"\n\x06points\x18\x04 \x03(\x0b\x32\x12.hdmap_lib.Point3D\x12\x0e\n\x06length\x18\x05 \x01(\x01\"\x1e\n\x05\x43olor\x12\t\n\x05WHITE\x10\x01\x12\n\n\x06YELLOW\x10\x02\"z\n\x04Type\x12\x08\n\x04NONE\x10\x01\x12\t\n\x05SOLID\x10\x02\x12\n\n\x06\x42ROKEN\x10\x03\x12\x10\n\x0c\x44OUBLE_SOLID\x10\x04\x12\x11\n\rDOUBLE_BROKEN\x10\x05\x12\x10\n\x0c\x42ROKEN_SOLID\x10\x06\x12\x10\n\x0cSOLID_BROKEN\x10\x07\x12\x08\n\x04\x43URB\x10\x08\"B\n\nLineString\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12\x19\n\nis_reverse\x18\x02 \x01(\x08:\x05\x66\x61lse\"-\n\x05\x43urve\x12$\n\x05lines\x18\x01 \x03(\x0b\x32\x15.hdmap_lib.LineString\"/\n\x07Polygon\x12$\n\x05lines\x18\x01 \x03(\x0b\x32\x15.hdmap_lib.LineString'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_id__pb2.DESCRIPTOR,])



_LINESTRINGDATA_COLOR = _descriptor.EnumDescriptor(
  name='Color',
  full_name='hdmap_lib.LineStringData.Color',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WHITE', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YELLOW', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=322,
  serialized_end=352,
)
_sym_db.RegisterEnumDescriptor(_LINESTRINGDATA_COLOR)

_LINESTRINGDATA_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='hdmap_lib.LineStringData.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOLID', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BROKEN', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE_SOLID', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE_BROKEN', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BROKEN_SOLID', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOLID_BROKEN', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CURB', index=7, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=354,
  serialized_end=476,
)
_sym_db.RegisterEnumDescriptor(_LINESTRINGDATA_TYPE)


_POINT3D = _descriptor.Descriptor(
  name='Point3D',
  full_name='hdmap_lib.Point3D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='hdmap_lib.Point3D.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='hdmap_lib.Point3D.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='hdmap_lib.Point3D.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=128,
)


_LINESTRINGDATA = _descriptor.Descriptor(
  name='LineStringData',
  full_name='hdmap_lib.LineStringData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.LineStringData.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color', full_name='hdmap_lib.LineStringData.color', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='hdmap_lib.LineStringData.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='points', full_name='hdmap_lib.LineStringData.points', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='hdmap_lib.LineStringData.length', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LINESTRINGDATA_COLOR,
    _LINESTRINGDATA_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=131,
  serialized_end=476,
)


_LINESTRING = _descriptor.Descriptor(
  name='LineString',
  full_name='hdmap_lib.LineString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.LineString.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_reverse', full_name='hdmap_lib.LineString.is_reverse', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=478,
  serialized_end=544,
)


_CURVE = _descriptor.Descriptor(
  name='Curve',
  full_name='hdmap_lib.Curve',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lines', full_name='hdmap_lib.Curve.lines', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=546,
  serialized_end=591,
)


_POLYGON = _descriptor.Descriptor(
  name='Polygon',
  full_name='hdmap_lib.Polygon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lines', full_name='hdmap_lib.Polygon.lines', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=593,
  serialized_end=640,
)

_LINESTRINGDATA.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LINESTRINGDATA.fields_by_name['color'].enum_type = _LINESTRINGDATA_COLOR
_LINESTRINGDATA.fields_by_name['type'].enum_type = _LINESTRINGDATA_TYPE
_LINESTRINGDATA.fields_by_name['points'].message_type = _POINT3D
_LINESTRINGDATA_COLOR.containing_type = _LINESTRINGDATA
_LINESTRINGDATA_TYPE.containing_type = _LINESTRINGDATA
_LINESTRING.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_CURVE.fields_by_name['lines'].message_type = _LINESTRING
_POLYGON.fields_by_name['lines'].message_type = _LINESTRING
DESCRIPTOR.message_types_by_name['Point3D'] = _POINT3D
DESCRIPTOR.message_types_by_name['LineStringData'] = _LINESTRINGDATA
DESCRIPTOR.message_types_by_name['LineString'] = _LINESTRING
DESCRIPTOR.message_types_by_name['Curve'] = _CURVE
DESCRIPTOR.message_types_by_name['Polygon'] = _POLYGON
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Point3D = _reflection.GeneratedProtocolMessageType('Point3D', (_message.Message,), {
  'DESCRIPTOR' : _POINT3D,
  '__module__' : 'proto.hdmap_lib.proto.geometry_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.Point3D)
  })
_sym_db.RegisterMessage(Point3D)

LineStringData = _reflection.GeneratedProtocolMessageType('LineStringData', (_message.Message,), {
  'DESCRIPTOR' : _LINESTRINGDATA,
  '__module__' : 'proto.hdmap_lib.proto.geometry_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LineStringData)
  })
_sym_db.RegisterMessage(LineStringData)

LineString = _reflection.GeneratedProtocolMessageType('LineString', (_message.Message,), {
  'DESCRIPTOR' : _LINESTRING,
  '__module__' : 'proto.hdmap_lib.proto.geometry_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LineString)
  })
_sym_db.RegisterMessage(LineString)

Curve = _reflection.GeneratedProtocolMessageType('Curve', (_message.Message,), {
  'DESCRIPTOR' : _CURVE,
  '__module__' : 'proto.hdmap_lib.proto.geometry_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.Curve)
  })
_sym_db.RegisterMessage(Curve)

Polygon = _reflection.GeneratedProtocolMessageType('Polygon', (_message.Message,), {
  'DESCRIPTOR' : _POLYGON,
  '__module__' : 'proto.hdmap_lib.proto.geometry_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.Polygon)
  })
_sym_db.RegisterMessage(Polygon)


# @@protoc_insertion_point(module_scope)
